@@ -10,7 +10,7 @@ from .performance import *
 from .propulsion import *
 from .structures import *
 
-__version__ = "3.2.13"
+__version__ = "3.2.14"
 
 
 def docs():
@@ -21,3 +21,14 @@ def docs():
     webbrowser.open_new(
         "https://github.com/peterdsharpe/AeroSandbox/tree/master/aerosandbox"
     )  # TODO: make this redirect to a hosted ReadTheDocs, or similar.
+
+def run_tests():
+    import pytest
+    import matplotlib.pyplot as plt
+    from pathlib import Path
+
+    asb_root = Path(__file__).parent
+
+    with plt.ion(): # Disable blocking plotting
+
+        pytest.main([str(asb_root)])
\ No newline at end of file
