@@ -12,5 +12,5 @@ def test_aero_buildup():
 
 
 if __name__ == '__main__':
-    test_aero_buildup()
+    aero = test_aero_buildup()
     # pytest.main()
