@@ -4,8 +4,12 @@ from aerosandbox.library.aerodynamics.viscous import Cf_flat_plate
 
 
 def print_default_warning():
-    warnings.warn("Warning: Using a default flat-plate aerodynamics model for this airfoil!\n"
-                  "To use a better, more accurate one, specify functions in the Airfoil constructor.")
+    warnings.warn("\n".join([
+        "Warning: Using a placeholder aerodynamics model for this Airfoil!",
+        "It's highly recommended that you either:",
+        "\ta) Specify polar functions in the Airfoil constructor, or",
+        "\tb) Call Airfoil.generate_polars() to auto-generate these polar functions with XFoil."
+    ]), stacklevel=3)
 
 
 def default_CL_function(alpha, Re, mach=0, deflection=0):
@@ -13,7 +17,7 @@ def default_CL_function(alpha, Re, mach=0, deflection=0):
     Lift coefficient.
     """
     print_default_warning()
-    Cl_inc = 2 * np.pi * np.radians(alpha)
+    Cl_inc = np.pi * np.sind(2 * alpha)
     beta = (1 - mach) ** 2
 
     Cl = Cl_inc * beta
@@ -25,9 +29,14 @@ def default_CD_function(alpha, Re, mach=0, deflection=0):
     Drag coefficient.
     """
     print_default_warning()
-    Cf = Cf_flat_plate(Re_L=Re)
-    Cd_inc = 2 * Cf * (
-            1 + (alpha / 5) ** 2
+    Cf = Cf_flat_plate(Re_L=Re, method="hybrid-sharpe-convex")
+
+    ### Form factor model from Raymer, "Aircraft Design". Section 12.5, Eq. 12.30
+    t_over_c = 0.12
+    FF = 1 + 2 * t_over_c * 100 * t_over_c ** 4
+
+    Cd_inc = 2 * Cf * FF * (
+            1 + (np.sind(alpha) * 180 / np.pi / 5) ** 2
     )
     beta = (1 - mach) ** 2
 
