@@ -35,7 +35,7 @@ class Wing(AeroSandboxObject):
                  name: str = "Untitled Wing",
                  xsecs: List['WingXSec'] = [],
                  symmetric: bool = False,
-                 xyz_le: np.ndarray = None,  # TODO deprecate in favor of a ".translate()"-like method.
+                 xyz_le: np.ndarray = None,  # Note: deprecated.
                  ):
         """
         Initialize a new wing.
@@ -50,7 +50,9 @@ class Wing(AeroSandboxObject):
         if xyz_le is not None:
             import warnings
             warnings.warn(
-                "The `xyz_le` input for Wing is DEPRECATED and will be removed in a future version. Use Wing().translate(xyz) instead.")
+                "The `xyz_le` input for Wing is DEPRECATED and will be removed in a future version. Use Wing().translate(xyz) instead.",
+                stacklevel=2
+            )
             self.xsecs = [
                 xsec.translate(xyz_le)
                 for xsec in xsecs
@@ -819,11 +821,11 @@ class WingXSec(AeroSandboxObject):
                  xyz_le: np.ndarray = np.array([0, 0, 0]),
                  chord: float = 1.,
                  twist: float = 0,
-                 airfoil: Airfoil = Airfoil("naca0012"),
+                 airfoil: Airfoil = None,
                  control_surface_is_symmetric: bool = True,
                  control_surface_hinge_point: float = 0.75,
                  control_surface_deflection: float = 0.,
-                 twist_angle=None,  # TODO Deprecate
+                 twist_angle=None,  # Note: deprecated.
                  ):
         """
         Initialize a new wing cross section.
@@ -837,13 +839,19 @@ class WingXSec(AeroSandboxObject):
                     * That direction vector is projected onto the Y-Z plane.
                     * That direction vector is now the twist axis.
             airfoil: Airfoil associated with this cross section. [aerosandbox.Airfoil]
-            control_surface_is_symmetric: Is the control surface symmetric? (e.g. True for flaps, False for ailerons.)
+            control_surface_is_symmetric: Is the control surface symmetric? (e.g., True for flaps, False for ailerons.)
             control_surface_hinge_point: The location of the control surface hinge, as a fraction of chord.
             control_surface_deflection: Control deflection, in degrees. Downwards-positive.
         """
+        if airfoil is None:
+            airfoil = Airfoil("naca0012")
+
         if twist_angle is not None:
             import warnings
-            warnings.warn("DEPRECATED: 'twist_angle' has been renamed 'twist', and will break in future versions.")
+            warnings.warn(
+                "DEPRECATED: 'twist_angle' has been renamed 'twist', and will break in future versions.",
+                stacklevel=2
+            )
             twist = twist_angle
 
         self.xyz_le = np.array(xyz_le)
@@ -898,4 +906,4 @@ if __name__ == '__main__':
             )
         ]
     )
-    wing.draw()
\ No newline at end of file
+    wing.draw()
