@@ -5,8 +5,8 @@ import aerosandbox.library.aerodynamics as aero
 
 
 def plot_Cf_flat_plates():
-    sns.set(palette=sns.color_palette("husl"))
-    fig, ax = plt.subplots(1, 1, figsize=(6.4, 4.8), dpi=200)
+    from aerosandbox.tools.pretty_plots import plt, show_plot
+
     Res = np.geomspace(1e3, 1e8, 500)
     for method in [
         "blasius",
@@ -21,14 +21,12 @@ def plot_Cf_flat_plates():
             aero.Cf_flat_plate(Res, method=method),
             label=method
         )
-    plt.xlabel(r"$Re$")
-    plt.ylabel(r"$C_f$")
     plt.ylim(1e-3, 1e-1)
-    plt.title(r"Models for Mean Skin Friction Coefficient of Flat Plate")
-    plt.tight_layout()
-    plt.legend()
-    plt.show()
-
+    show_plot(
+        "Models for Mean Skin Friction Coefficient of Flat Plate",
+        r"$Re$",
+        r"$C_f$",
+    )
 
 if __name__ == '__main__':
     plot_Cf_flat_plates()
