@@ -1,8 +1,6 @@
 from aerosandbox.modeling.fitting import FittedModel
 import pytest
 import aerosandbox.numpy as np
-import matplotlib.pyplot as plt
-import seaborn as sns
 
 
 def test_fit_model_weighting():
@@ -20,7 +18,7 @@ def test_fit_model_weighting():
         weights=None
     )  # Fit a model with no weighting
 
-    assert fm(10) != pytest.approx(5, abs=1) # Doesn't give a high value at x = 10
+    assert fm(10) != pytest.approx(5, abs=1)  # Doesn't give a high value at x = 10
 
     fm = FittedModel(
         model=lambda x, p: p["m"] * x + p["b"],
@@ -33,7 +31,7 @@ def test_fit_model_weighting():
         weights=(x > 0) & (x < 2)
     )  # Fit a model with weighting
 
-    assert fm(10) == pytest.approx(5, abs=1) # Gives a high value at x = 10
+    assert fm(10) == pytest.approx(5, abs=1)  # Gives a high value at x = 10
 
     fm.plot()
 
