@@ -37,6 +37,13 @@ def test_interpolated_model_plot():
     model.plot()
 
 
+def test_interpolated_model_zeros_patch():
+    x = np.array([1, 2, 3, 4, 5])
+    y = 0 * x
+    f = InterpolatedModel(x, y)(3)
+    assert f == pytest.approx(0)
+
+
 if __name__ == '__main__':
-    test_interpolated_model_at_scalar()
-    # pytest.main()
+    test_interpolated_model_zeros_patch()
+    pytest.main()
